==> deploy-0.0.11.jar: kepler16/deploy.clj <==
(ns kepler16.deploy
  (:require
   [clojure.string :as str]
   [clojure.java.shell :as sh]
   [hf.depstar.uberjar :as depstar]
   [kepler16.github :as github]
   [kepler16.pom :as pom]))

(set! *warn-on-reflection* true)

(defn deploy-file [{:keys [group-id artifact repo-id repository-url jar-file pom]
                    :or {pom "pom.xml"
                         repo-id "github"
                         repository-url (str "https://maven.pkg.github.com/" group-id "/" artifact)}}]
  (str
   "mvn deploy:deploy-file"
   " -DrepositoryId=" repo-id
   " -Durl=" repository-url
   " -Dfile=" jar-file
   " -DpomFile=" pom))

(defn deploy-github-maven-package [{:keys [group-id artifact repo-id repository-url jar-file pom token version] :as package}]
  (if (github/package-exists? {:repo artifact
                               :org group-id
                               :version version
                               :token token})
    "echo \"Package already exists.\""
    (deploy-file package)))

(defn deploy-clojars-maven-package [package]
  (deploy-file (assoc package
                      :repository-url "https://clojars.org/repo")))


(defn deploy-clojars!
  [{:keys [jar] :as options}]
  {:pre [(string? jar)]}
  (let [pom (pom/load-pom!)
        command
        (deploy-clojars-maven-package {:group-id (pom/pom->group-id pom)
                                       :artifact (pom/pom->artifact pom)
                                       :repo-id "clojars"
                                       :jar-file jar
                                       :version (pom/pom->version pom)})
        result
        (as-> command $
          (str/split $ #" ")
          (apply sh/sh $))]
    (println (:out result))
    (binding [*out* *err*]
      (println (:err result)))))

(defn deploy-github!
  [{:keys [jar] :as options}]
  {:pre [(string? jar)]}
  (let [pom (pom/load-pom!)
        command
        (deploy-github-maven-package {:token (System/getenv "GITHUB_TOKEN")
                                      :group-id (pom/pom->group-id pom)
                                      :artifact (pom/pom->artifact pom)
                                      :repo-id "github"
                                      :jar-file jar
                                      :version (pom/pom->version pom)})
        _ (println command)
        result
        (as-> command $
          (str/split $ #" ")
          (apply sh/sh $))]

    (println (:out result))
    (binding [*out* *err*]
      (println (:err result)))))


(defn build-and-deploy-to-clojars! [options]
  (let [result (depstar/build-jar options)]
    (if (:success result)
      (do
        (deploy-clojars! options)
        (shutdown-agents))
      (System/exit 1))))

==> deploy-0.1.0.jar: kepler16/deploy.clj <==
(ns kepler16.deploy
  (:require
   [clojure.string :as str]
   [clojure.java.shell :as sh]
   [hf.depstar.uberjar :as depstar]
   [kepler16.github :as github]
   [kepler16.pom :as pom]))

(set! *warn-on-reflection* true)

(defn deploy-file [{:keys [group-id artifact repo-id repository-url jar-file pom]
                    :or {pom "pom.xml"
                         repo-id "github"
                         repository-url (str "https://maven.pkg.github.com/" group-id "/" artifact)}}]
  (str
   "mvn deploy:deploy-file"
   " -DrepositoryId=" repo-id
   " -Durl=" repository-url
   " -Dfile=" jar-file
   " -DpomFile=" pom))

(defn deploy-github-maven-package [{:keys [group-id artifact repo-id repository-url jar-file pom token version] :as package}]
	(deploy-file package)
	#_
  (if (github/package-exists? {:repo artifact
																				 :org group-id
																				 :version version
																				 :token token})
    "echo \"Package already exists.\""
    (deploy-file package)))

(defn deploy-clojars-maven-package [package]
  (deploy-file (assoc package
                      :repository-url "https://clojars.org/repo")))

(defn deploy-clojars!
  [{:keys [jar] :as options}]
  {:pre [(string? jar)]}
  (let [pom (pom/load-pom!)
        command
        (deploy-clojars-maven-package {:group-id (pom/pom->group-id pom)
                                       :artifact (pom/pom->artifact pom)
                                       :repo-id "clojars"
                                       :jar-file jar
                                       :version (pom/pom->version pom)})
        result
        (as-> command $
          (str/split $ #" ")
          (apply sh/sh $))]
    (println (:out result))
    (binding [*out* *err*]
      (println (:err result)))))

(defn deploy-github!
  [{:keys [jar] :as options}]
  {:pre [(string? jar)]}
  (let [pom (pom/load-pom!)
        command
        (deploy-github-maven-package {:token (System/getenv "GITHUB_TOKEN")
                                      :group-id (pom/pom->group-id pom)
                                      :artifact (pom/pom->artifact pom)
                                      :repo-id "github"
                                      :jar-file jar
                                      :version (pom/pom->version pom)})
        _ (println command)
        result
        (as-> command $
          (str/split $ #" ")
          (apply sh/sh $))]

    (println (:out result))
    (binding [*out* *err*]
      (println (:err result)))))

(defn build-and-deploy! [{:keys [target] :or {target :github} :as options}]
	(let [result (depstar/build-jar options)]
    (if (:success result)
      (do
				(case target
					:github (deploy-github! options)
					:clojars (deploy-clojars! options))
        (shutdown-agents))
      (System/exit 1))))

(comment
	(build-and-deploy!
	 {:target :github
		:jar "target/lib.jar"
		:jar-type :thin
		:sync-pom true
		:verbose true
		:group-id 'kepler16
		:artifact-id 'deploy
		:version "0.0.11"}))
